@@ -1,6 +1,19 @@
 from bot.utilsbot import *
-from bot.helptexts import *
 from bot.callbacks import *
+from bot.helptexts import (
+    welcomehelpp,
+    filterrhelp,
+    promotehelpp,
+    banhelpp,
+    kickhelpp,
+    pinhelpp,
+    purgehelpp,
+    notesshelp,
+    lockktypes,
+    lockhelpp,
+    fedhelpp,
+)
+
 import csv
 import json
 import os
