@@ -11,6 +11,7 @@ from bot.helptexts import (
     lockktypes,
     lockhelpp,
     fedhelpp,
+    ruless,
 )
 from telethon import events, functions, Button
 import bot.utilsbot
@@ -54,3 +55,7 @@ async def _(event):
 @callback("fedhelp")
 async def _(event):
     await event.edit(f"{fedhelpp}",buttons=[Button.inline(" <-- Back", data="helpstarter")])
+
+@callback("ruleshelp")
+async def _(event):
+    await event.edit(f"{ruless}",buttons=[Button.inline(" <-- Back", data="helpstarter")])
